============
The Guardian
============

.. automodule:: orangecontrib.text.guardian


.. autoclass:: orangecontrib.text.guardian.TheGuardianCredentials
   :members:
   :special-members: __init__


.. autoclass:: orangecontrib.text.guardian.TheGuardianAPI
   :members:
   :special-members: __init__

